==> objc-bootstrap-3.1.33.tar.gz: objc-bootstrap-3.1.33/lexfiltr.c <==
# 1 "lexfiltr.m"
struct _PRIVATE { struct _PRIVATE *isa; };
typedef struct _PRIVATE *id;
struct _SHARED {
  id isa;
  id clsSuper;
  char *clsName;
  char *clsTypes;
  short clsSizInstance;
  short clsSizDict;
  struct _SLT *clsDispTable;
  long clsStatus;
  struct modDescriptor *clsMod;
  unsigned clsVersion;
  id clsCats;
  id *clsGlbl;
};
extern id  (* _imp(id,char*))();
extern id  (* _impSuper(id,char*))();
extern struct modDescriptor  *_OBJCBIND_lexfiltr(void);
static char **selTransTbl;
struct _SLT {char *_cmd;id (*_imp)();};
struct modDescriptor {
  char *modName;
  char *modVersion;
  long modStatus;
  char *modMinSel;
  char *modMaxSel;
  id *modClsLst;
  short modSelRef;
  char **modSelTbl;
  struct methodDescriptor *modMapTbl;
};
extern struct modDescriptor lexfiltr_modDesc;

# 1 "../../util/stdlib.h"
#include <stdlib.h>

# 1 "../../util/stdio.h"
#include <stdio.h>

# 1 "../../util/string.h"
#include <string.h>

# 1 "../../util/stdio.h"
#include <stdio.h>

# 1 "../../util/stddef.h"
#include <stddef.h>

# 53 "../../include/objcrt/objcrt.h"
typedef char*SEL;
typedef char*STR;
typedef char BOOL;
typedef FILE*IOD;
typedef id SHR;
# 62 "../../include/objcrt/objcrt.h"
typedef id(*IMP)();


typedef void(*ARGIMP)(id,SEL,void*);
# 85 "../../include/objcrt/objcrt.h"
extern BOOL msgFlag;
extern FILE*msgIOD;
extern FILE*dbgIOD;
extern BOOL allocFlag;
extern BOOL dbgFlag;
extern BOOL noCacheFlag;
extern BOOL noNilRcvr;
# 98 "../../include/objcrt/objcrt.h"
SEL selUid(STR);
STR selName(SEL);
void dbg(char*fmt,...);
void prnstack(FILE*file);
void loadobjc(void*modPtr);
void unloadobjc(void*modPtr);
# 107 "../../include/objcrt/objcrt.h"
IMP fwdimp(id,SEL,IMP);
IMP fwdimpSuper(id,SEL,IMP);
void fwdmsg(id,SEL,void*,ARGIMP);
id selptrfwd(id,SEL,id,id,id,id);


id idincref(id obj);
id idassign(id*lhs,id rhs);
id iddecref(id obj);

extern id(*_fileIn)(FILE*);
extern BOOL(*_fileOut)(FILE*,id);
extern BOOL(*_storeOn)(STR,id);
extern id(*_readFrom)(STR);
void setfilein(id(*f)(FILE*));
void setfileout(BOOL(*f)(FILE*,id));

extern id(*_showOn)(id,unsigned);

void*OC_Malloc(size_t);
void*OC_MallocAtomic(size_t);
void*OC_Calloc(size_t);
void*OC_Realloc(void*,size_t);
void*OC_Free(void*data);
# 1 "../../util/string.h"
#include <string.h>

# 38 "../../include/objcrt/Block.h"
extern id newBlock(int n,IMP fn,void*data,IMP dtor);
# 23 "../oclib/util.h"
extern FILE*yyin;
extern int yyparse();

FILE*openfile(STR name,STR modfs);
FILE*reopenfile(STR name,STR modfs,FILE*of);

extern int okblock;

id mkcppdirect(char*s);
id mkexprstmt(id expr);
id mklabeledstmt(id label,id stmt);
id mkcasestmt(id keyw,id expr,id stmt);
id mkdefaultstmt(id keyw,id stmt);
id mkifstmt(id keyw,id expr,id stmt);
id mkifelsestmt(id keyw,id expr,id stmt,id ekeyw,id estmt);
id mkswitchstmt(id keyw,id expr,id stmt);
id mkwhilestmt(id keyw,id expr,id stmt);
id mkdostmt(id keyw,id stmt,id wkeyw,id expr);
id mkforstmt(id keyw,id a,id b,id c,id stmt);
id mkgotostmt(id keyw,id label);
id mkcontinuestmt(id keyw);
id mkbreakstmt(id keyw);
id mkreturnstmt(id keyw,id expr);
id mkcastexpr(id a,id b);
id mkcondexpr(id a,id b,id c);
id mkunaryexpr(STR op,id a);
id mksizeof(id a);
id mktypeof(id kw,id a);
id mkaddressof(id a);
id mkdereference(id a);
id mkbinexpr(id a,STR op,id b);
id mkcommaexpr(id a,id b);
id mkrelexpr(id a,STR op,id b);
id mkassignexpr(id a,STR op,id b);
id mkfuncall(id funname,id args);
id mkbuiltincall(id funname,id args);
id mkfunbody(id datadefs,id compound);
void declarefun(id specs,id decl);
void declaremeth(BOOL factory,id decl);
id mkfundef(id specs,id decl,id body);
id mkmethdef(BOOL factory,id decl,id body);
id mkmesgexpr(id receiver,id args);
id mkdecl(id ident);
id mkprecdecl(id tquals,id decl);
id mkarraydecl(id lhs,id ix);
id mkfundecl(id lhs,id args);
id mkprefixdecl(id lhs,id rhs);
id mkpostfixdecl(id lhs,id rhs);
id mkpointer(id specs,id pointer);
id mkbitfielddecl(id decl,id expr);
id mkstardecl(id pointer,id decl);
id mkasmop(id string,id expr);
id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
id mklist(id c,id s);
id mklist2(id c,id s,id t);
id atdefsaddall(id c,id n);
id mkblockexpr(id lb,id parms,id datadefs,id stmts,id expr,id rb);
id mkclassdef(id keyw,id name,id sname,id ivars,id cvars);
id mkdatadef(id datadef,id specs,id decl,id initializer);
id mkencodeexpr(id name);
id mkenumspec(id keyw,id name,id lb,id list,id rb);
id mkenumerator(id name,id value);
id mkgnuattrib(id anyword,id exprlist);
id mkgnuattribdecl(id keyw,id list);
id mklistexpr(id lb,id x,id rb);
id mktypename(id specs,id decl);
id mkcomponentdef(id cdef,id specs,id decl);
id mkstructspec(id keyw,id name,id lb,id defs,id rb);
id mkkeywarg(id sel,id arg);
id mkkeywdecl(id sel,id cast,id arg);
id mkmethproto(id cast,id usel,id ksel,BOOL varargs);
id mkidentexpr(id name);
id mkconstexpr(id name,id schain);
id mkprecexpr(id expr);
id mkbracedgroup(id expr);
id mkarrowexpr(id array,id ix);
id mkdotexpr(id array,id ix);
id mkindexexpr(id array,id ix);
id mkpostfixexpr(id expr,id pf);
id mkparmdef(id parmdef,id specs,id decl);
id mkparmdeflist(id idents,id parmdefs,BOOL varargs);
id mkselarg(id selarg,id usel,int ncols);
id mkselectorexpr(id expr);

void procextdef(id def);
void finclassdef(void);
void datadefokblock(id datadef,id specs,id decl);

id mkfileinmeth(id classdef,id ivarnames,id ivartypes);
id mkfileoutmeth(id classdef,id ivarnames,id ivartypes);

id mkincrefsmeth(id classdef,id ivarnames,id ivartypes);
id mkdecrefsmeth(id classdef,id ivarnames,id ivartypes);
# 22 "../oclib/options.h"
void defoptions(void);

extern int o_warnings;
extern int o_gnu;
extern int o_vms;
extern int o_refcnt;
extern int o_ppi;
extern int o_watcom;
extern int o_ibmvac;
extern int o_msdos;
extern int o_enableasm;
extern int o_nolinetags;
extern int o_buffered;
extern int o_quiet;
extern int o_outputcode;
extern int o_version;
extern int o_otb;
extern int o_llkeyw;
extern int o_comments;
extern int o_duptypedefs;
extern int o_seltranslation;
extern int o_categories;
extern int o_blocks;
extern int o_fwd;
extern int o_selptr;
extern int o_cache;
extern int o_filer;
extern int o_selfassign;
extern char*o_bind;
extern char*o_browsedir;
extern int o_refbind;
extern int o_inlinecache;
extern int o_cplus;
extern int o_gencode;
extern int o_st80;
extern int o_selfassign;
extern int o_nilrcvr;
extern int o_shareddata;
extern int o_oneperfile;
extern int o_cvars;
extern int o_warnlex;
extern int o_warnfwd;
extern int o_warnsuggest;
extern int o_warnintvar;
extern int o_warnclasstype;
extern int o_warntypeconflict;
extern int o_warnundefined;
extern int o_warnlocalnst;
extern int o_warnnotfound;
extern int o_warnmissingmethods;
extern int o_postlink;
extern char*o_infile;
extern char*o_outfile;
extern char*o_srcfilename;
extern char*o_initcall;
extern char*o_tagformat;
extern char*o_mainfun;
extern char*o_pathsep;
extern int o_debuginfo;
extern int o_checkbind;
extern int o_linemax;
extern int o_structassign;
extern id o_stepbreak;
extern int o_stepnext;
# 110 "lexfiltr.m"
extern int yylex_raw(void);

extern BOOL isbuiltinfun(id x);
extern BOOL istypeword(id x);


extern char*yytext;
extern int okblock;
# 139 "lexfiltr.m"
struct nesting
{
int braces;
int brackets;
int parens;
};

extern id yylval;
# 156 "lexfiltr.m"
struct token
{
int original;
int filtered;
id yylval;
int okblock;
# 171 "lexfiltr.m"
};

# 185 "lexfiltr.m"
static void get_token(struct token*token)
{
token->original=yylex_raw();
token->filtered=token->original;


token->yylval=yylval;
token->okblock=okblock;
# 200 "lexfiltr.m"
}

# 205 "lexfiltr.m"
static void restore_globals(const struct token*token)
{
yylval=token->yylval;
okblock=token->okblock;
}

# 216 "lexfiltr.m"
static void eval_nesting(struct nesting*n,int token)
{
switch(token)
{
case'[':
n->braces++;
break;

case']':
n->braces--;
break;

case'{':
n->brackets++;
break;

case'}':
n->brackets--;
break;

case'(':
n->parens++;
break;

case')':
n->parens--;
break;
}
}

# 250 "lexfiltr.m"
static BOOL same_nesting(
const struct nesting*n0,
const struct nesting*n1)
{
return((n0->braces==n1->braces)&&
(n0->brackets==n1->brackets)&&
(n0->parens==n1->parens));
}

# 266 "lexfiltr.m"
int yylex()
{
if( !o_duptypedefs){

return yylex_raw();
}
else{


static BOOL first=(BOOL)1;
static struct nesting currentlevel;
static struct nesting typedeflevel;
# 285 "lexfiltr.m"
static int typedef_count;
static int lparen_count;
static struct token token,nexttoken;

if(first){
get_token( &nexttoken);
first=(BOOL)0;
}


token=nexttoken;
restore_globals( &nexttoken);
get_token( &nexttoken);

if(typedef_count)
typedef_count++;

eval_nesting( &currentlevel,token.original);

switch(token.original){


case 263:
typedef_count=1;
lparen_count=0;
typedeflevel=currentlevel;
# 315 "lexfiltr.m"
token.filtered=262;
break;


case';':
if((typedef_count)&&
(same_nesting( &currentlevel, &typedeflevel)))
{
typedef_count=0;
}
break;

case 257:
if(isbuiltinfun(token.yylval)){
token.filtered=260;
}
else if(istypeword(token.yylval)){
# 338 "lexfiltr.m"
token.filtered=261;
# 350 "lexfiltr.m"
if(typedef_count>2)
{
# 357 "lexfiltr.m"
if((same_nesting( &currentlevel, &typedeflevel))&&
((nexttoken.original==';')||(nexttoken.original==',')))
{
token.filtered=257;
}
# 369 "lexfiltr.m"
else if((currentlevel.braces==typedeflevel.braces)&&
(currentlevel.brackets==typedeflevel.brackets)&&
(currentlevel.parens==typedeflevel.parens+1)&&
(lparen_count==1)&&
(nexttoken.original==')'))
{
token.filtered=257;
}
}
}
break;

case'(':
if(typedef_count)
lparen_count++;
break;

case',':
if((typedef_count)&&
(same_nesting( &currentlevel, &typedeflevel)))
lparen_count=0;
break;

}
# 396 "lexfiltr.m"
restore_globals( &token);
return token.filtered;
}
}
static char *_selTransTbl[] ={
0
};
struct modDescriptor lexfiltr_modDesc = {
  "lexfiltr",
  "objc3.1.33",
  0L,
  0,
  0,
  0,
  0,
  0,
  0
};
struct modDescriptor *_OBJCBIND_lexfiltr(void)
{
  selTransTbl = _selTransTbl;
  return &lexfiltr_modDesc;
}
int _OBJCPOSTLINK_lexfiltr = 1;

==> objc-bootstrap-3.2.8.tar.gz: objc-bootstrap-3.2.8/lexfiltr.c <==
# 1 "lexfiltr.m"
struct _PRIVATE { struct _PRIVATE *isa; };
typedef struct _PRIVATE *id;
struct _SHARED {
  id isa;
  id clsSuper;
  char *clsName;
  char *clsTypes;
  short clsSizInstance;
  short clsSizDict;
  struct _SLT *clsDispTable;
  long clsStatus;
  struct modDescriptor *clsMod;
  unsigned clsVersion;
  id clsCats;
  id *clsGlbl;
};
extern id  (* _imp(id,char*))();
extern id  (* _impSuper(id,char*))();
extern struct modDescriptor  *_OBJCBIND_lexfiltr(void);
static char **selTransTbl;
struct _SLT {char *_cmd;id (*_imp)();};
struct modDescriptor {
  char *modName;
  char *modVersion;
  long modStatus;
  char *modMinSel;
  char *modMaxSel;
  id *modClsLst;
  short modSelRef;
  char **modSelTbl;
  struct methodDescriptor *modMapTbl;
};
extern struct modDescriptor lexfiltr_modDesc;

# 1 "../../util/stdlib.h"
#include <stdlib.h>

# 1 "../../util/stdio.h"
#include <stdio.h>

# 1 "../../util/string.h"
#include <string.h>

# 1 "../../util/stdio.h"
#include <stdio.h>

# 1 "../../util/stddef.h"
#include <stddef.h>

# 53 "../../include/objcrt/objcrt.h"
typedef char*SEL;
typedef char*STR;
typedef char BOOL;
typedef FILE*IOD;
typedef id SHR;
# 62 "../../include/objcrt/objcrt.h"
typedef id(*IMP)();


typedef void(*ARGIMP)(id,SEL,void*);
# 85 "../../include/objcrt/objcrt.h"
extern BOOL msgFlag;
extern FILE*msgIOD;
extern FILE*dbgIOD;
extern BOOL allocFlag;
extern BOOL dbgFlag;
extern BOOL noCacheFlag;
extern BOOL noNilRcvr;
# 98 "../../include/objcrt/objcrt.h"
SEL selUid(STR);
STR selName(SEL);
void dbg(char*fmt,...);
void prnstack(FILE*file);
void loadobjc(void*modPtr);
void unloadobjc(void*modPtr);
# 107 "../../include/objcrt/objcrt.h"
IMP fwdimp(id,SEL,IMP);
IMP fwdimpSuper(id,SEL,IMP);
void fwdmsg(id,SEL,void*,ARGIMP);
id selptrfwd(id,SEL,id,id,id,id);


id idincref(id obj);
id idassign(id*lhs,id rhs);
id iddecref(id obj);

extern id(*_fileIn)(FILE*);
extern BOOL(*_fileOut)(FILE*,id);
extern BOOL(*_storeOn)(STR,id);
extern id(*_readFrom)(STR);
void setfilein(id(*f)(FILE*));
void setfileout(BOOL(*f)(FILE*,id));

extern id(*_showOn)(id,unsigned);

void*OC_Malloc(size_t);
void*OC_MallocAtomic(size_t);
void*OC_Calloc(size_t);
void*OC_Realloc(void*,size_t);
void*OC_Free(void*data);
# 1 "../../util/string.h"
#include <string.h>

# 38 "../../include/objcrt/Block.h"
extern id newBlock(int n,IMP fn,void*data,IMP dtor);
# 23 "../oclib/util.h"
extern FILE*yyin;
extern int yyparse();

FILE*openfile(STR name,STR modfs);
FILE*reopenfile(STR name,STR modfs,FILE*of);

extern int okblock;

id mkcppdirect(char*s);
id mkexprstmt(id expr);
id mklabeledstmt(id label,id stmt);
id mkcasestmt(id keyw,id expr,id stmt);
id mkdefaultstmt(id keyw,id stmt);
id mkifstmt(id keyw,id expr,id stmt);
id mkifelsestmt(id keyw,id expr,id stmt,id ekeyw,id estmt);
id mkswitchstmt(id keyw,id expr,id stmt);
id mkwhilestmt(id keyw,id expr,id stmt);
id mkdostmt(id keyw,id stmt,id wkeyw,id expr);
id mkforstmt(id keyw,id a,id b,id c,id stmt);
id mkgotostmt(id keyw,id label);
id mkcontinuestmt(id keyw);
id mkbreakstmt(id keyw);
id mkreturnstmt(id keyw,id expr);
id mkcastexpr(id a,id b);
id mkcondexpr(id a,id b,id c);
id mkunaryexpr(STR op,id a);
id mksizeof(id a);
id mktypeof(id kw,id a);
id mkaddressof(id a);
id mkdereference(id a);
id mkbinexpr(id a,STR op,id b);
id mkcommaexpr(id a,id b);
id mkrelexpr(id a,STR op,id b);
id mkassignexpr(id a,STR op,id b);
id mkfuncall(id funname,id args);
id mkbuiltincall(id funname,id args);
id mkfunbody(id datadefs,id compound);
void declarefun(id specs,id decl);
void declaremeth(BOOL factory,id decl);
id mkfundef(id specs,id decl,id body);
id mkmethdef(BOOL factory,id decl,id body);
id mkmesgexpr(id receiver,id args);
id mkdecl(id ident);
id mkprecdecl(id tquals,id decl);
id mkarraydecl(id lhs,id ix);
id mkfundecl(id lhs,id args);
id mkprefixdecl(id lhs,id rhs);
id mkpostfixdecl(id lhs,id rhs);
id mkpointer(id specs,id pointer);
id mkbitfielddecl(id decl,id expr);
id mkstardecl(id pointer,id decl);
id mkasmop(id string,id expr);
id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
id mkcompstmt(id lb,id datadefs,id stmtlist,id subblock,id rb);
id mklist(id c,id s);
id mklist2(id c,id s,id t);
id atdefsaddall(id c,id n);
id mkblockexpr(id lb,id parms,id datadefs,id stmts,id expr,id rb);
id mkclassdef(id keyw,id name,id sname,id ivars,id cvars);
id mkdatadef(id datadef,id specs,id decl,id initializer);
id mkencodeexpr(id name);
id mkenumspec(id keyw,id name,id lb,id list,id rb);
id mkenumerator(id name,id value);
id mkgnuattrib(id anyword,id exprlist);
id mkgnuattribdecl(id keyw,id list);
id mklistexpr(id lb,id x,id rb);
id mktypename(id specs,id decl);
id mkcomponentdef(id cdef,id specs,id decl);
id mkstructspec(id keyw,id name,id lb,id defs,id rb);
id mkkeywarg(id sel,id arg);
id mkkeywdecl(id sel,id cast,id arg);
id mkmethproto(id cast,id usel,id ksel,BOOL varargs);
id mkidentexpr(id name);
id mkconstexpr(id name,id schain);
id mkprecexpr(id expr);
id mkbracedgroup(id expr);
id mkarrowexpr(id array,id ix);
id mkdotexpr(id array,id ix);
id mkindexexpr(id array,id ix);
id mkpostfixexpr(id expr,id pf);
id mkparmdef(id parmdef,id specs,id decl);
id mkparmdeflist(id idents,id parmdefs,BOOL varargs);
id mkselarg(id selarg,id usel,int ncols);
id mkselectorexpr(id expr);

void procextdef(id def);
void finclassdef(void);
void datadefokblock(id datadef,id specs,id decl);

id mkfileinmeth(id classdef,id ivarnames,id ivartypes);
id mkfileoutmeth(id classdef,id ivarnames,id ivartypes);

id mkincrefsmeth(id classdef,id ivarnames,id ivartypes);
id mkdecrefsmeth(id classdef,id ivarnames,id ivartypes);
# 22 "../oclib/options.h"
void defoptions(void);

extern int o_warnings;
extern int o_gnu;
extern int o_hpux;
extern int o_vms;
extern int o_refcnt;
extern int o_ppi;
extern int o_watcom;
extern int o_ibmvac;
extern int o_msdos;
extern int o_enableasm;
extern int o_nolinetags;
extern int o_buffered;
extern int o_quiet;
extern int o_outputcode;
extern int o_version;
extern int o_otb;
extern int o_llkeyw;
extern int o_comments;
extern int o_duptypedefs;
extern int o_seltranslation;
extern int o_categories;
extern int o_blocks;
extern int o_fwd;
extern int o_selptr;
extern int o_cache;
extern int o_filer;
extern int o_selfassign;
extern char*o_bind;
extern char*o_browsedir;
extern int o_refbind;
extern int o_inlinecache;
extern int o_cplus;
extern int o_gencode;
extern int o_st80;
extern int o_selfassign;
extern int o_nilrcvr;
extern int o_shareddata;
extern int o_oneperfile;
extern int o_cvars;
extern int o_warnlex;
extern int o_warnfwd;
extern int o_warnsuggest;
extern int o_warnintvar;
extern int o_warnclasstype;
extern int o_warntypeconflict;
extern int o_warnundefined;
extern int o_warnlocalnst;
extern int o_warnnotfound;
extern int o_warnmissingmethods;
extern int o_postlink;
extern char*o_infile;
extern char*o_outfile;
extern char*o_srcfilename;
extern char*o_initcall;
extern char*o_tagformat;
extern char*o_mainfun;
extern char*o_pathsep;
extern int o_debuginfo;
extern int o_checkbind;
extern int o_linemax;
extern int o_structassign;
extern id o_stepbreak;
extern int o_stepnext;
# 110 "lexfiltr.m"
extern int yylex_raw(void);

extern BOOL isbuiltinfun(id x);
extern BOOL istypeword(id x);


extern char*yytext;
extern int okblock;
# 139 "lexfiltr.m"
struct nesting
{
int braces;
int brackets;
int parens;
};

extern id yylval;
# 156 "lexfiltr.m"
struct token
{
int original;
int filtered;
id yylval;
int okblock;
# 171 "lexfiltr.m"
};

# 185 "lexfiltr.m"
static void get_token(struct token*token)
{
token->original=yylex_raw();
token->filtered=token->original;


token->yylval=yylval;
token->okblock=okblock;
# 200 "lexfiltr.m"
}

# 205 "lexfiltr.m"
static void restore_globals(const struct token*token)
{
yylval=token->yylval;
okblock=token->okblock;
}

# 216 "lexfiltr.m"
static void eval_nesting(struct nesting*n,int token)
{
switch(token)
{
case'[':
n->braces++;
break;

case']':
n->braces--;
break;

case'{':
n->brackets++;
break;

case'}':
n->brackets--;
break;

case'(':
n->parens++;
break;

case')':
n->parens--;
break;
}
}

# 250 "lexfiltr.m"
static BOOL same_nesting(
const struct nesting*n0,
const struct nesting*n1)
{
return((n0->braces==n1->braces)&&
(n0->brackets==n1->brackets)&&
(n0->parens==n1->parens));
}

# 266 "lexfiltr.m"
int yylex()
{
if( !o_duptypedefs){

return yylex_raw();
}
else{


static BOOL first=(BOOL)1;
static struct nesting currentlevel;
static struct nesting typedeflevel;
# 285 "lexfiltr.m"
static int typedef_count;
static int lparen_count;
static struct token token,nexttoken;

if(first){
get_token( &nexttoken);
first=(BOOL)0;
}


token=nexttoken;
restore_globals( &nexttoken);
get_token( &nexttoken);

if(typedef_count)
typedef_count++;

eval_nesting( &currentlevel,token.original);

switch(token.original){


case 263:
typedef_count=1;
lparen_count=0;
typedeflevel=currentlevel;
# 315 "lexfiltr.m"
token.filtered=262;
break;


case';':
if((typedef_count)&&
(same_nesting( &currentlevel, &typedeflevel)))
{
typedef_count=0;
}
break;

case 257:
if(isbuiltinfun(token.yylval)){
token.filtered=260;
}
else if(istypeword(token.yylval)){
# 338 "lexfiltr.m"
token.filtered=261;
# 350 "lexfiltr.m"
if(typedef_count>2)
{
# 357 "lexfiltr.m"
if((same_nesting( &currentlevel, &typedeflevel))&&
((nexttoken.original==';')||(nexttoken.original==',')))
{
token.filtered=257;
}
# 369 "lexfiltr.m"
else if((currentlevel.braces==typedeflevel.braces)&&
(currentlevel.brackets==typedeflevel.brackets)&&
(currentlevel.parens==typedeflevel.parens+1)&&
(lparen_count==1)&&
(nexttoken.original==')'))
{
token.filtered=257;
}
}
}
break;

case'(':
if(typedef_count)
lparen_count++;
break;

case',':
if((typedef_count)&&
(same_nesting( &currentlevel, &typedeflevel)))
lparen_count=0;
break;

}
# 396 "lexfiltr.m"
restore_globals( &token);
return token.filtered;
}
}
static char *_selTransTbl[] ={
0
};
struct modDescriptor lexfiltr_modDesc = {
  "lexfiltr",
  "objc3.2.8",
  0L,
  0,
  0,
  0,
  0,
  0,
  0
};
struct modDescriptor *_OBJCBIND_lexfiltr(void)
{
  selTransTbl = _selTransTbl;
  return &lexfiltr_modDesc;
}
int _OBJCPOSTLINK_lexfiltr = 1;
